@@ -1,4 +1,4 @@
-#' Expectation: is returned value less or greater than specified value?
+#' Does code return a number greater/less than the expected value?
 #'
 #' @inheritParams expect_equal
 #' @param expected Single numeric value to compare.
@@ -36,7 +36,8 @@ expect_compare <- function(operator = c("<", "<=", ">", ">="), act, exp) {
   }
   expect(
     if (!is.na(cmp)) cmp else FALSE,
-    sprintf("%s is %s %s. Difference: %.3g", act$lab, msg, exp$lab, act$val - exp$val)
+    sprintf("%s is %s %s. Difference: %.3g", act$lab, msg, exp$lab, act$val - exp$val),
+    trace_env = caller_env()
   )
   invisible(act$val)
 }
